from setuptools import setup

setup(name='strings_from_file',
      version='0.1',
      description='Get strings from file and rewrite file',
      packages=['strings_from_file'],
      author_email='nazarkalashnikovkalashnikov@yandex.ru',
      zip_safe=False)
